# lockfile
Создание файла блокировки, для предотвращения выполнения нескольких копий скрипта.

Использование
```
from pylockfile import * #Импорт модуля

lf = pylockfile('<PATH_TO_FILE>') #Указание пути до файла блокировки

lf.create() #Создание файла блокировки в начале скрипта

lf.delete() # Удаление файла блокировки в конце скрипта
```
